@@ -2,13 +2,13 @@ package LCFG::Build::Tools;    # -*-cperl-*-
 use strict;
 use warnings;
 
-# $Id: Tools.pm.in 5773 2010-01-18 18:09:28Z squinney@INF.ED.AC.UK $
+# $Id: Tools.pm.in 12894 2010-07-12 15:44:11Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tools.pm.in,v $
-# $Revision: 5773 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_0_58/lib/LCFG/Build/Tools.pm.in $
-# $Date: 2010-01-18 18:09:28 +0000 (Mon, 18 Jan 2010) $
+# $Revision: 12894 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_2_2/lib/LCFG/Build/Tools.pm.in $
+# $Date: 2010-07-12 16:44:11 +0100 (Mon, 12 Jul 2010) $
 
-our $VERSION = '0.0.58';
+our $VERSION = '0.2.2';
 
 use Moose;
 
@@ -29,7 +29,7 @@ __END__
 
 =head1 VERSION
 
-This documentation refers to LCFG::Build::Tools version 0.0.58
+This documentation refers to LCFG::Build::Tools version 0.2.2
 
 =head1 DESCRIPTION
 
@@ -145,7 +145,7 @@ L<LCFG::Build::Pkgspec> and L<LCFG::Build::VCS>.
 
 The templates are processed using the perl Template Toolkit.
 
-For building RPM packages you will need the L<RPM4> module.
+For building RPM packages you will need C<rpmbuild>.
 
 You will also need L<Archive::Tar>, L<DateTime>, L<File::Find::Rule>,
 L<IO::Zlib>, L<Text::Abbreviate>, L<UNIVERSAL::require> and
@@ -161,7 +161,7 @@ This is the list of platforms on which we have tested this
 software. We expect this software to work on any Unix-like platform
 which is supported by Perl.
 
-FedoraCore5, FedoraCore6, ScientificLinux5
+Fedora12, Fedora13, ScientificLinux5
 
 =head1 BUGS AND LIMITATIONS
 
